@@ -25,6 +25,8 @@
 
 #include <gst/gst.h>
 #include <gst/base/gstbasesink.h>
+#include <gst/video/video-prelude.h>
+#include <gst/video/video-info.h>
 
 G_BEGIN_DECLS
 
@@ -105,7 +107,7 @@ struct _GstVideoSink {
  * @parent_class: the parent class structure
  * @show_frame: render a video frame. Maps to #GstBaseSinkClass.render() and
  *     #GstBaseSinkClass.preroll() vfuncs. Rendering during preroll will be
- *     suppressed if the #GstVideoSink:show-preroll-frame property is set to 
+ *     suppressed if the #GstVideoSink:show-preroll-frame property is set to
  *     %FALSE.
  *
  * The video sink class structure. Derived classes should override the
@@ -116,18 +118,35 @@ struct _GstVideoSinkClass {
 
   GstFlowReturn  (*show_frame) (GstVideoSink *video_sink, GstBuffer *buf);
 
+  /**
+   * GstVideoSinkClass::set_info:
+   * @caps: A #GstCaps.
+   * @info: A #GstVideoInfo corresponding to @caps.
+   *
+   * Notifies the subclass of changed #GstVideoInfo.
+   *
+   * Since: 1.20
+   */
+  gboolean       (*set_info)   (GstVideoSink *video_sink, GstCaps *caps, const GstVideoInfo *info);
+
   /*< private >*/
-  gpointer _gst_reserved[GST_PADDING];
+  gpointer _gst_reserved[GST_PADDING-1];
 };
 
+GST_VIDEO_API
 GType gst_video_sink_get_type (void);
 
+GST_VIDEO_DEPRECATED_FOR(gst_video_center_rect)
 void gst_video_sink_center_rect (GstVideoRectangle src, GstVideoRectangle dst,
                                  GstVideoRectangle *result, gboolean scaling);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+GST_VIDEO_API
+void gst_video_center_rect      (const GstVideoRectangle * src,
+                                 const GstVideoRectangle * dst,
+                                 GstVideoRectangle * result,
+                                 gboolean scaling);
+
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstVideoSink, gst_object_unref)
-#endif
 
 G_END_DECLS
 
